Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(124)

Unified Diff: net/base/cert_verifier.h

Issue 125120: Use LOAD_VERIFY_EV_CERT to verify EV-ness in Verify().... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/renderer_host/resource_dispatcher_host.cc ('k') | net/base/cert_verifier.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/base/cert_verifier.h
===================================================================
--- net/base/cert_verifier.h (revision 19005)
+++ net/base/cert_verifier.h (working copy)
@@ -42,9 +42,15 @@
// |verify_result->cert_status|, and the error code for the most serious
// error is returned.
//
// If |rev_checking_enabled| is true, certificate revocation checking is
// performed.
//
+ // If VERIFY_EV_CERT is set on |flags| too, EV certificate verification is
+ // performed. If |flags| is VERIFY_EV_CERT (that is,
+ // VERIFY_REV_CHECKING_ENABLED is not set), EV certificate verification will
+ // not be performed.
+ //
// When callback is null, the operation completes synchronously.
//
// When callback is non-null, ERR_IO_PENDING is returned if the operation
@@ -52,7 +58,7 @@
// be passed to the callback when available.
//
int Verify(X509Certificate* cert, const std::string& hostname,
- bool rev_checking_enabled, CertVerifyResult* verify_result,
+ int flags, CertVerifyResult* verify_result,
CompletionCallback* callback);
private:
« no previous file with comments | « chrome/browser/renderer_host/resource_dispatcher_host.cc ('k') | net/base/cert_verifier.cc » ('j') | no next file with comments »
@@ -42,9 +42,15 @@
// error is returned.
//
- // If |rev_checking_enabled| is true, certificate revocation checking is
- // performed.
+ // |flags| is OR'd of X509Certificate::VerifyFlags.
+ // If VERIFY_REV_CHECKING_ENABLED is set on |flags|, certificate revocation
+ // checking is performed.
//

Powered by Google App Engine
This is Rietveld 408576698